<?php

namespace Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;
use \Teknisa\Model\Teknisa\Entities as TeknisaEntities;
use Doctrine\DBAL\Connection;

class CustomizationFilesFactory
{
    use TQuery;
    private $connection;

    private $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getPais()
    {
        $conditions = '';
        $sql = "SELECT *
		  FROM ( SELECT P.CDPAIS, P.NMPAIS, P.NRORG, P.CDESOCIAL,
                   CASE WHEN P.NMPAIS LIKE 'Brasil' THEN 1 ELSE 2 END AS ORDPAIS
                   FROM PAIS P
                  ORDER BY ORDPAIS, NMPAIS)
         WHERE 1=1
		       $conditions";
  
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getEstado($idPais){
        $conditions = '';
        $sql = "SELECT *
		  FROM ( SELECT E.SGESTADO, E.NMESTADO, E.CDPAIS
                   FROM ESTADO E
                  WHERE E.CDPAIS = :CDPAIS
               ORDER BY E.NMESTADO)
         WHERE 1=1
		       $conditions";

        $params = array(
            "CDPAIS" => $idPais
        );

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function getMunicipio($sigla){
        $conditions = '';
        $sql = "SELECT *
		  FROM ( SELECT M.CDMUNICIPIO, M.NMMUNICIPIO, M.SGESTADO AS STATE_SYMBOL
                   FROM MUNICIPIO M
                  WHERE M.SGESTADO = :SGESTADO
               ORDER BY M.NMMUNICIPIO )
         WHERE 1=1
		 $conditions
        ";

        $params = array(
            "SGESTADO" => $sigla
        );
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function getUseLicense($cdCliente)
    {
        $sql = "SELECT CDLINPCLIE,NMLINPCLIE,IDMPROCLINPC,IDLPROCLINPC,NRUSUALINPC,
                      NRACESLINPC,IDTIPLINPC, (IDMPROCLINPC || '/' || IDLPROCLINPC) AS IDMLPROCLINPC
                  FROM CONTRATOLINP
                  WHERE CDCLIENTE     = :CDCLIENTE
                  AND DTCONTLINPRESC IS NULL
                  ORDER BY CDLINPCLIE  ";

        $params = array(
            'CDCLIENTE' => $cdCliente,
        );
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function saveLicencauso($cdlocaluso, $nmfantluso, $nmrazsocluso, $nrinsjurluso, $nrinsestluso,
                                     $nrinsmuniluso, $nmcontluso, $nmdeptoluso, $idfaturafilisep, $dsendeluso, $nmbairluso,
                                     $nrcepluso, $cdpais, $sgestado, $cdmunicipio, $nrteleluso, $nrramalluso, $nrfaxluso,
                                     $dsemailcomlu, $cdCliente, $nrlicencauso, $idmodproc, $idlocaproc, $entity, $idlusoativ = 'S', $nrlimcone = 1, $idtpijurluso = 'J'){

        if(!$entity){
            $entity = new TeknisaEntities\Licencauso();
            $entity->setCdlocaluso($cdlocaluso);
            $entity->setNrlicencauso($nrlicencauso);
            $entity->setCdcliente($cdCliente);
        }
        $entity->setIdlusoativ($idlusoativ);
        $entity->setNmfantluso($nmfantluso);
        $entity->setNmrazsocluso($nmrazsocluso);
        $entity->setNrinsjurluso($nrinsjurluso);
        $entity->setNrinsestluso($nrinsestluso);
        $entity->setNrinsmuniluso($nrinsmuniluso);
        $entity->setNmcontluso($nmcontluso);
        $entity->setNmdeptoluso($nmdeptoluso);
        $entity->setIdfaturafilisep($idfaturafilisep);
        $entity->setDsendeluso($dsendeluso);
        $entity->setNmbairluso($nmbairluso);
        $entity->setIdtpijurluso($idtpijurluso);
        $entity->setNrcepluso($nrcepluso);
        $entity->setCdpais($cdpais);
        $entity->setSgestado($sgestado);
        $entity->setCdmunicipio($cdmunicipio);
        $entity->setNrteleluso($nrteleluso);
        $entity->setNrramalluso($nrramalluso);
        $entity->setNrfaxluso($nrfaxluso);
        $entity->setDsemailcomlu($dsemailcomlu);
        $entity->setNrlimconex($nrlimcone);
        $entity->setIdmodproc($idmodproc);
        $entity->setIdlocaproc($idlocaproc);
        return $entity;
    }

    public function createLinpluso($cdcliente, $nrlicencauso, $cdlinpclie, $idlinpexcluida = 'N'){
        $entity = new TeknisaEntities\Linpluso();
        $entity->setCdcliente($cdcliente);
        $entity->setNrlicencauso($nrlicencauso);
        $entity->setCdlinpclie($cdlinpclie);
        $entity->setIdlinpexcluida($idlinpexcluida);

        return $entity;
    }

    public function inativarLicensaUso($cdcliente, $arrayLicensauso) {
        $query = 
        "   UPDATE LICENCAUSO
            SET IDLUSOATIV = 'N'
            WHERE CDCLIENTE = :CDCLIENTE AND NRLICENCAUSO IN (:NRLICENCAUSO) ";
        $params = array (
            'CDCLIENTE'     => $cdcliente,
            'NRLICENCAUSO'  => $arrayLicensauso,
        );
        $paramTypes = array(
            'NRLICENCAUSO' => Connection::PARAM_STR_ARRAY
        );
        $this->entityManager->getConnection()->executeQuery($query, $params, $paramTypes);
    }
}