<?php

namespace Service\Teknisa;

use Doctrine\DBAL\Connection;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class AlphanumericNewCode extends StoredProcedure {

    public function __construct($procedureName = 'NOVO_CODIGO_ALFA') {
        $connection = \Setforms2\Shared\Registry::getEntityManagerConnection();
        parent::__construct($connection, $procedureName);
    }

    /**
     * Format a code generated by the new code, making cast to int
     * or return the value based on column size.
     *
     * @param      $code
     * @param      $colSize
     *
     * @return int|string
     */
    protected function formatValue($code, $colSize) {
        return substr($code, -1 * $colSize);
    }

    /**
     * Return a code generated by the procedure
     *
     * @param      $tableName
     * @param      $nrorg
     * @param int  $interval
     * @param int  $colSize
     *
     * @return int|string
     */
    public function getCodeByTableName($tableName, $nrorg, $interval = 1, $colSize = 10) {

        $this->addParam(new Param('P_CONTADOR', Param::PARAM_INPUT, $tableName.'ALFA', Param::PARAM_TYPE_STR));
        $this->addParam(new Param('P_SEQUENCIAL', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 20));
        $this->addParam(new Param('P_QTDE', Param::PARAM_INPUT, $interval, Param::PARAM_TYPE_INT));
        $this->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $nrorg, Param::PARAM_TYPE_INT));
        $code = $this->execute();
        // clear params
        $this->params = array();

        return $this->formatValue($code['P_SEQUENCIAL'], $colSize);

    }

} 