import { Utilities } from '@/util/Utilities';
import { FileInput, LoadingService } from '@zeedhi/common';
import { Config, Http, MemoryDatasource, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class InativarPERUnidadeController {
    public colorirLinha: boolean = false;

    public async leituraArquivoPersonalizadoInPER() {
        LoadingService.show();
        const grid = Metadata.getInstance<TekGrid>('gridExibicaoArquivoInPER');
        const file = await Utilities.buildArrayToUpload('ARQUIVO');
        grid.datasource.data = [];
        (grid.datasource as MemoryDatasource).allData = [];
        if (file.length !== 0) {
            const response = await Http.post('/validaArquivoPersonalizado', {
                FILE: file,
            });
            const formattedData = this.formattedData(response);
            formattedData.forEach((element: any) => {
                const dados: any = {
                    CDLOCALUSO: element.CDLOCALUSO,
                };
                grid.datasource.post(dados);
            });
        }
        grid.datasource.get();
        LoadingService.hide();
    }

    public colorirLinhasInválidas() {
        let erroEncontrado = false;
        if (this.colorirLinha === true) {
            erroEncontrado = true;
        }
        if (erroEncontrado) {
            return { cssClass: 'linhaGridVermelha' };
        }
        return undefined;
    }

    public formattedData(response: any) {
        const arraysFromBackend: string[][] = response.data;

        // Nomes dos elementos que você deseja
        const elementNames = ['CDLOCALUSO'];

        const formattedData = arraysFromBackend.slice(1).map((array) => {
            const obj: { [key: string]: any } = {};
            elementNames.forEach((elementName, i) => {
                obj[elementName] = array[i];
            });
            return obj;
        });

        return formattedData;
    }

    public downloadPlanilhaPadraoInPER() {
        window.open(`${Config.endPoint}/downloadPlanilhaPadraoInPER`);
    }

    public async inativarLocaisUsoArquivoPersonalizado() {
        const grid = Metadata.getInstance<TekGrid>('gridExibicaoArquivoInPER');
        const dados = (grid.datasource as MemoryDatasource).allData;
        if (dados.length > 0) {
            LoadingService.show();
            Http.post('/inativarLocaisUsoArquivoPersonalizado', dados)
                .then(() => {
                    grid.datasource.data = [];
                    (grid.datasource as MemoryDatasource).allData = [];
                    Metadata.getInstance<FileInput>('ARQUIVO').value = null;
                    Utilities.showSuccessMessage();
                }).catch((error) => {
                    Utilities.showErrorMessage(error);
                }).finally(() => {
                    LoadingService.hide();
                });
        } else {
            Utilities.showDialog('Erro!', 'error', 'O grid deve conter pelo menos um registro.');
        }
    }
}
